!!****if* source/Simulation/SimulationMain/Sod/Simulation_init
!!
!! NAME
!!
!!  Simulation_init
!!
!!
!! SYNOPSIS
!!
!!  Simulation_init(integer(in) :: myPE)
!!
!!
!! DESCRIPTION
!!
!!  Initializes all the parameters needed for the Sod shock tube
!!  problem
!!
!! ARGUMENTS
!!
!!
!! PARAMETERS
!!
!!
!!***

subroutine Simulation_init()
  
  use Simulation_data
  use Driver_interface, ONLY : Driver_getMype

  use Driver_data, ONLY : dr_restart
  use RuntimeParameters_interface, ONLY : RuntimeParameters_get
  use Logfile_interface, ONLY : Logfile_stamp
  use Eos_data, ONLY : eos_gamma, eos_singleSpeciesA, eos_gasConstant
  use Grid_data, ONLY: gr_imin, gr_imax, gr_jmin, gr_jmax, gr_kmin, gr_kmax

  implicit none

#include "Flash.h"
#include "constants.h"
#include "Eos.h"

  double precision :: mtot, qX, qZ, vol, dummy

  integer i, myPE, ierr

  call Driver_getMyPE(MESH_COMM,myPE)

  call RuntimeParameters_get('smallx', sim_smallx)
  call RuntimeParameters_get('smallt', sim_smallt)
  call RuntimeParameters_get('smlrho', sim_smlrho)

  call RuntimeParameters_get('gradDir', sim_gradDir)
  call RuntimeParameters_get('velDir', sim_velDir)

  call RuntimeParameters_get('gamma',eos_gamma)
  call RuntimeParameters_get('rhoAmbient', sim_rhoAmb)
  call RuntimeParameters_get('rhoAmbient2', sim_rhoAmb2)
  call RuntimeParameters_get('presAmbient',sim_presAmb)

  call RuntimeParameters_get('vdrift',sim_vdrift)

  if (sim_rhoAmb .gt. 0.d0) then
    if (sim_presAmb .gt. 0.d0) then
      sim_tempAmb = sim_presAmb/(eos_gasConstant*sim_rhoAmb/eos_singleSpeciesA)
      sim_eintAmb = eos_gasConstant*sim_tempAmb/((eos_gamma-1.d0)*eos_singleSpeciesA)
    else
      call Driver_abortFlash("Need to give at least 2 ambient state variables.")
    endif
  else
    call Driver_abortFlash("Need to give at least 2 ambient state variables.")
  endif

  if (myPE .eq. MASTER_PE) then
    write(6,*) "Using following ambient variables: "
    write(6,*) "DENSITY:  ", sim_rhoAmb
    write(6,*) "TEMP:     ", sim_tempAmb
    write(6,*) "EINT:     ", sim_eintAmb
    write(6,*) "PRESSURE: ", sim_presAmb
    write(6,*) "ABAR:     ", eos_singleSpeciesA
    write(6,*) "GAMMA:  ", eos_gamma
  endif

  sim_gridChanged = 1

  call Logfile_stamp("initializing SPHinit problem",  &
       "[Simulation_init]")
     
end subroutine Simulation_init







